@@ -1,6 +1,6 @@
-from bread import layout
-from bread.utils import Link, ModelHref, pretty_modelname
-from bread.views import BrowseView
+from basxbread import layout
+from basxbread.utils import Link, ModelHref
+from basxbread.views import BrowseView
 from django.utils.translation import gettext_lazy as _
 
 from basxconnect.core.models import Term, Vocabulary
@@ -23,7 +23,7 @@ class TermsBrowseView(BrowseView):
                         query={"vocabulary": vocabulary.id},
                         return_to_current=True,
                     ),
-                    label=_("Add %s") % pretty_modelname(Term),
+                    label=_("Add %s") % Term._meta.verbose_name,
                 ),
                 icon=layout.icon.Icon("add", size=20),
             )
