@@ -1,6 +1,6 @@
 import htmlgenerator as hg
-from bread.utils import Link, ModelHref
-from bread.views import BrowseView
+from basxbread.utils import Link, ModelHref
+from basxbread.views import BrowseView
 from django.utils.translation import gettext_lazy as _
 
 from basxconnect.core.models import Term
