@@ -1,9 +1,8 @@
 import htmlgenerator as hg
-from bread import layout
-from bread.forms.forms import breadmodelform_factory
-from bread.utils import pretty_modelname
-from bread.utils.urls import reverse_model
-from bread.views import BreadView
+from basxbread import layout
+from basxbread.forms.forms import modelform_factory
+from basxbread.utils.urls import reverse_model
+from basxbread.views import BaseView
 from django import forms
 from django.apps import apps
 from django.contrib.auth.mixins import PermissionRequiredMixin
@@ -71,6 +70,8 @@ def ADD_EMAIL_LAYOUT():
             layout.grid.Col(
                 layout.forms.FormField("email", elementattributes={"required": False})
             ),
+        ),
+        layout.grid.Row(
             layout.grid.Col(layout.forms.FormField("type")),
         ),
         gutter=False,
@@ -107,7 +108,7 @@ def generate_wizard_form(formlayout):
                 hg.If(
                     hg.F(
                         lambda c: c["wizard"]["steps"].last
-                        == c["wizard"]["steps"].current
+                                  == c["wizard"]["steps"].current
                     ),
                     layout.button.Button(
                         _("Complete"), type="submit", style="margin-left: 1rem"
@@ -160,9 +161,9 @@ class SearchForm(forms.Form):
 
 class ChooseType(forms.Form):
     PERSON_TYPES = {
-        "core.NaturalPerson": pretty_modelname(NaturalPerson),
-        "core.LegalPerson": pretty_modelname(LegalPerson),
-        "core.PersonAssociation": pretty_modelname(PersonAssociation),
+        "core.NaturalPerson": NaturalPerson._meta.verbose_name,
+        "core.LegalPerson": LegalPerson._meta.verbose_name,
+        "core.PersonAssociation": PersonAssociation._meta.verbose_name,
     }
     persontype = forms.TypedChoiceField(
         label=_("Type of person"),
@@ -226,17 +227,17 @@ class ConfirmNewPerson(forms.Form):
 
 
 def generate_add_form_for(model, request, data, files, initial=None):
-    form = breadmodelform_factory(
+    form = modelform_factory(
         request=request, model=model, layout=ADD_FORM_LAYOUTS[model]()
     )(data, files, initial=initial)
 
-    for fieldname, field in breadmodelform_factory(
-        request, Postal, ADD_ADDRESS_LAYOUT()
+    for fieldname, field in modelform_factory(
+            request, Postal, ADD_ADDRESS_LAYOUT()
     )().fields.items():
         form.fields[fieldname] = field
 
-    for fieldname, field in breadmodelform_factory(
-        request, Email, ADD_EMAIL_LAYOUT()
+    for fieldname, field in modelform_factory(
+            request, Email, ADD_EMAIL_LAYOUT()
     )().fields.items():
         form.fields[fieldname] = field
 
@@ -257,7 +258,7 @@ def generate_add_form_for(model, request, data, files, initial=None):
 
 
 # The WizardView contains mostly control-flow logic and some configuration
-class AddPersonWizard(PermissionRequiredMixin, BreadView, NamedUrlSessionWizardView):
+class AddPersonWizard(PermissionRequiredMixin, BaseView, NamedUrlSessionWizardView):
     kwargs = {"url_name": "core:person:add_wizard", "urlparams": {"step": "str"}}
     urlparams = (("step", str),)
     permission_required = "core.add_person"
@@ -307,7 +308,7 @@ class AddPersonWizard(PermissionRequiredMixin, BreadView, NamedUrlSessionWizardV
             layout.grid.Grid(
                 layout.grid.Row(
                     layout.grid.Col(
-                        generate_wizard_form(self.get_form()._layout), width=8
+                        generate_wizard_form(self.get_form()._layout), width=12
                     )
                 ),
                 gutter=False,
@@ -377,7 +378,7 @@ class AddPersonWizard(PermissionRequiredMixin, BreadView, NamedUrlSessionWizardV
                     for fieldname in form.fields:
                         form.fields[fieldname].disabled = True
                         form.fields[fieldname].widget.attrs["style"] = "color: #000"
-                form.title = _("Add %s") % pretty_modelname(persontype)
+                form.title = _("Add %s") % persontype._meta.verbose_name
         return form
 
     def done(self, form_list, **kwargs):
