@@ -2,9 +2,9 @@ from django.utils.translation import gettext_lazy as _
 from dynamic_preferences.preferences import Section
 from dynamic_preferences.registries import global_preferences_registry
 from dynamic_preferences.types import (
-    BooleanPreference,
     LongStringPreference,
     StringPreference,
+    BooleanPreference,
 )
 
 mailchimp_integration = Section("mailchimp", _("Mailchimp"))
@@ -66,9 +66,25 @@ class MailchimpApiKey(LongStringPreference):
     verbose_name = _("Mailchimp API key")
 
 
+@global_preferences_registry.register
+class MailchimpDisableInterestsKey(BooleanPreference):
+    section = mailchimp_integration
+    name = "disable_interests"
+    default = False
+    verbose_name = _("Disable mailing interests")
+
+
 @global_preferences_registry.register
 class MailchimpSynchronizeLanguage(BooleanPreference):
     section = mailchimp_integration
     name = "synchronize_language"
     default = False
-    verbose_name = _("synchronize preferred language of contact with Mailchimp")
+    verbose_name = _("Synchronize language with Mailchimp")
+
+
+@global_preferences_registry.register
+class MailchimpAutomaticallySubscribeNewPersons(BooleanPreference):
+    section = mailchimp_integration
+    name = "automatically_subscribe_new_persons"
+    default = False
+    verbose_name = _("Automatically subscribe new persons")
